#!/usr/bin/env node
/*!
 * gitmars v7.0.0-beta.27
 * 这是一个git工作流工具
 * (c) 2021-2024 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import chalk from 'chalk';
import { getConfig, getIsGitProject, getGitRevParse } from '@gitmars/git';
import { writeFile } from '@gitmars/utils';
import lang from './common/local.mjs';
import { defaults } from './common/global.mjs';

const { t } = lang;
const { green, red } = chalk;
const config = getConfig();
if (!getIsGitProject()) {
  sh.echo(red(t("The current directory is not a git project directory")));
  process.exit(1);
}
program.name("gitm config").usage("<option> [value]").command("set <option> [value]").description(t("Set configuration items for gitmars")).action(async (option, value) => {
  let { filepath } = config;
  if (!filepath) {
    const { root } = getGitRevParse();
    filepath = root + "/.gitmarsrc";
  }
  if (value) {
    if (Object.keys(defaults).includes(option)) {
      config[option] = value;
      delete config.filepath;
      delete config.skipCI;
      await writeFile(filepath, JSON.stringify(config, null, 4));
      sh.echo(green(t("Saved successfully")));
      process.exit(0);
    } else {
      sh.echo(
        red(
          t("The configuration item {option} is not supported", {
            option
          })
        )
      );
      process.exit(1);
    }
  } else {
    sh.echo(t("Enter the items to be configured"));
    process.exit(1);
  }
});
program.name("gitm config").usage("list [option]").command("list [option]").description(t("Query single or all gitmars for configuration items")).action((option) => {
  if (option) {
    sh.echo(green(config[option]));
  } else {
    sh.echo(green(config));
  }
  process.exit(0);
});
program.parse(process.argv);
