#!/usr/bin/env node
/*!
 * gitmars v7.0.0-beta.27
 * 这是一个git工作流工具
 * (c) 2021-2024 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import chalk from 'chalk';
import to from 'await-to-done';
import { confirm } from '@inquirer/prompts';
import { queue } from '@gitmars/core';
import { getIsGitProject, getGitStatus } from '@gitmars/git';
import { createArgs } from '@gitmars/utils';
import { getCommandCache, cleanCommandCache } from '@gitmars/cache';
import { cmdConfig } from './conf/continue.mjs';
import lang from './common/local.mjs';

const { t } = lang;
const { green, red, yellow } = chalk;
const { args, options } = cmdConfig;
if (!getIsGitProject()) {
  sh.echo(red(t("The current directory is not a git project directory")));
  process.exit(1);
}
program.name("gitm continue").usage("[-l --list]").description(t("Continue unfinished operations"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action(async (opt) => {
  const sum = getGitStatus();
  const cmd = getCommandCache();
  if (opt.list) {
    console.info(cmd);
    process.exit(0);
  }
  if (cmd.length > 0) {
    if (sum.A.length > 0 || sum.D.length > 0 || sum.M.length > 0 || sum.UU.length > 0) {
      const [, answer] = await to(
        confirm({
          message: t(
            "A conflict has been detected in the merge branch and you need to run git add . Do you want to force the script to continue?"
          ),
          default: false
        })
      );
      if (!answer) {
        sh.echo(green(t("exited")));
        process.exit(0);
      }
    } else if (sum["??"].length > 0) {
      sh.echo(yellow(t("An uncommitted file was detected, please be aware!")));
    }
    queue(cmd).then(() => {
      cleanCommandCache();
    });
  } else {
    sh.echo(red(t("There are no unexecuted commands in the queue")));
  }
});
program.parse(process.argv);
