#!/usr/bin/env node
/*!
 * gitmars v7.0.0-beta.27
 * 这是一个git工作流工具
 * (c) 2021-2024 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import chalk from 'chalk';
import { select, Separator } from '@inquirer/prompts';
import { getProperty } from 'js-cool';
import to from 'await-to-done';
import { getCurrentBranch } from '@gitmars/git';
import { createArgs } from '@gitmars/utils';
import lang from './common/local.mjs';
import * as index from './go/index.mjs';
import { cmdConfig } from './conf/go.mjs';

const { t } = lang;
const { green, red } = chalk;
const { args, options } = cmdConfig;
program.name("gitm go").usage("[command]").description(t("Intelligent guessing of the action you want to perform"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action(async (command) => {
  const current = getCurrentBranch();
  sh.echo(
    green(
      t("Current branch is {current}, I suspect you may want to do the following: ", {
        current
      })
    )
  );
  if (command) {
    const cmd = getProperty(index, command);
    if (!cmd) {
      sh.echo(
        red(
          t("The command you entered was not found and may not be supported at this time")
        )
      );
      process.exit(1);
    }
    cmd();
  } else {
    const [, command2 = ""] = await to(
      select({
        message: t("Please select the operation you want?"),
        default: "combine",
        choices: [
          new Separator(" === 1. " + t("Gitmars Workflow") + " === "),
          { name: "combine", value: "combine" },
          { name: "end", value: "end" },
          { name: "update", value: "update" },
          { name: "build", value: "build" },
          { name: "start", value: "start" },
          { name: "undo", value: "undo" },
          { name: "redo", value: "redo" },
          { name: "admin.publish", value: "admin.publish" },
          { name: "admin.update", value: "admin.update" },
          { name: "admin.create", value: "admin.create" },
          { name: "admin.clean", value: "admin.clean" },
          new Separator(" === 2. " + t("Advanced Tools") + " === "),
          { name: "branch", value: "branch" },
          { name: "copy", value: "copy" },
          { name: "get", value: "get" },
          { name: "save", value: "save" },
          { name: "cleanbranch", value: "cleanbranch" },
          { name: "clean", value: "clean" },
          { name: "revert", value: "revert" },
          { name: "link", value: "link" },
          { name: "unlink", value: "unlink" },
          { name: "postmsg", value: "postmsg" },
          new Separator(" === " + t("Exit") + " === "),
          { name: "exit", value: "exit" },
          new Separator()
        ]
      })
    );
    if (command2 === "exit") {
      sh.echo(green(t("exited")));
      process.exit(0);
    }
    sh.echo(
      green(
        t("You have selected the {something} command", {
          something: command2
        })
      )
    );
    getProperty(index, command2)();
  }
});
program.parse(process.argv);
