#!/usr/bin/env node
/*!
 * gitmars v7.0.0-beta.27
 * 这是一个git工作流工具
 * (c) 2021-2024 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import { createArgs, spawnSync } from '@gitmars/utils';
import { cmdConfig } from './conf/link.mjs';
import lang from './common/local.mjs';

const { t } = lang;
const { args, options } = cmdConfig;
program.name("gitm link").usage("[name]").description(t("Link local package"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action((name) => {
  const isLink = sh.test("-L", `./node_modules/${name}`);
  const isExist = sh.test("-e", `./node_modules/${name}`);
  const npmClient = sh.which("yarn") ? "yarn" : "npm";
  if (!name) {
    const { status: status2 } = spawnSync(npmClient, ["link"]);
    if (status2 === 0)
      sh.echo(t("Processing completed"));
    else
      sh.echo(t("There was an error"));
    process.exit(0);
  } else if (isLink) {
    sh.rm("-rf", `./node_modules/${name}`);
  } else if (isExist) {
    sh.mv(`./node_modules/${name}`, `./node_modules/${name}_bak`);
  }
  const { status } = spawnSync(npmClient, ["link", name]);
  if (status === 0)
    sh.echo(t("Processing completed"));
  else {
    sh.echo(
      t(
        "Processing failed, {name} soft link does not exist, please go to the local {name} root directory and execute: gitm link",
        { name }
      )
    );
  }
});
program.parse(process.argv);
