#!/usr/bin/env node
/*!
 * gitmars v7.0.0-beta.27
 * 这是一个git工作流工具
 * (c) 2021-2024 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import dayjs from 'dayjs';
import columnify from 'columnify';
import chalk from 'chalk';
import { getIsGitProject, getGitLogs } from '@gitmars/git';
import { echo, createArgs } from '@gitmars/utils';
import { cmdConfig } from './conf/log.mjs';
import lang from './common/local.mjs';

const { t } = lang;
const { blue, cyan, green, red, yellow } = chalk;
const { args, options } = cmdConfig;
if (!getIsGitProject()) {
  echo(red(t("The current directory is not a git project directory")));
  process.exit(1);
}
program.name("gitm log").usage("[branch] [--lastet [lastet]] [--limit [limit]] [--no-merges] [--json]").description(t("Log query"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action(async (branch, opt) => {
  const logs = getGitLogs({
    lastet: opt.lastet,
    limit: opt.limit,
    branch,
    noMerges: !opt.merges
  });
  if (opt.json) {
    console.info(logs);
  } else {
    const data = logs.map((log) => ({
      commit: cyan(log["%h"]),
      merge: cyan(log["%p"]),
      title: green(log["%s"]),
      // author: yellow(`${log['%an']}<${log['%ae']}>`),
      author: yellow(log["%an"]),
      date: blue(dayjs(log["%aI"]).format("YYYY/MM/DD HH:mm:ss"))
    }));
    echo(columnify(data));
  }
  process.exit(0);
});
program.parse(process.argv);
