#!/usr/bin/env node
/*!
 * gitmars v7.0.0-beta.27
 * 这是一个git工作流工具
 * (c) 2021-2024 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import chalk from 'chalk';
import { queue } from '@gitmars/core';
import { getIsGitProject, getCurrentBranch } from '@gitmars/git';
import { createArgs } from '@gitmars/utils';
import lang from './common/local.mjs';
import { cmdConfig } from './conf/save.mjs';

const { t } = lang;
const { red } = chalk;
const { args, options } = cmdConfig;
if (!getIsGitProject()) {
  sh.echo(red(t("The current directory is not a git project directory")));
  process.exit(1);
}
program.name("gitm save").usage("[message] [-f --force]").description(t("Staging current branch files"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action((message, opt) => {
  if (!message)
    message = getCurrentBranch();
  message = `${message}_cache_by_gitmars`;
  let cmd = [
    {
      cmd: `git stash save "${message}"`,
      config: {
        success: t("File staging successful"),
        fail: t("There was an error, please contact an administrator")
      }
    }
  ];
  if (opt.force) {
    cmd = [
      "git add .",
      {
        cmd: `git stash save "${message}"`,
        config: {
          success: t("File staging successful"),
          fail: t("There was an error, please contact an administrator")
        }
      }
    ];
  }
  queue(cmd);
});
program.parse(process.argv);
