/*!
 * gitmars v7.0.0-beta.27
 * 这是一个git工作流工具
 * (c) 2021-2024 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { debug, spawnSync } from '@gitmars/utils';
import { getCurrentBranch } from '@gitmars/git';
import { cleanConfigSet, getCommand } from '@gitmars/go';
import { cmdConfig as cmdConfig$1 } from '../conf/combine.mjs';
import { cmdConfig as cmdConfig$2 } from '../conf/end.mjs';
import { cmdConfig as cmdConfig$3 } from '../conf/update.mjs';
import { cmdConfig as cmdConfig$4 } from '../conf/undo.mjs';
import { cmdConfig as cmdConfig$5 } from '../conf/redo.mjs';
import { cmdConfig as cmdConfig$6 } from '../conf/branch.mjs';
import { cmdConfig as cmdConfig$7 } from '../conf/build.mjs';
import { cmdConfig as cmdConfig$8 } from '../conf/build-mp.mjs';
import { cmdConfig } from '../conf/start.mjs';
import { cmdConfig as cmdConfig$9 } from '../conf/copy.mjs';
import { cmdConfig as cmdConfig$a } from '../conf/get.mjs';
import { cmdConfig as cmdConfig$b } from '../conf/save.mjs';
import { cmdConfig as cmdConfig$c } from '../conf/cleanbranch.mjs';
import { cmdConfig as cmdConfig$d } from '../conf/clean.mjs';
import { cmdConfig as cmdConfig$e } from '../conf/revert.mjs';
import { cmdConfig as cmdConfig$f } from '../conf/link.mjs';
import { cmdConfig as cmdConfig$g } from '../conf/unlink.mjs';
import { cmdConfig as cmdConfig$h } from '../conf/postmsg.mjs';
import { cmdConfig as cmdConfig$i } from '../conf/admin.mjs';

const {
  create: adminCreateConfig,
  publish: adminPublishConfig,
  update: adminUpdateConfig,
  clean: adminCleanConfig
} = cmdConfig$i;
const current = getCurrentBranch();
const branchPrefix = current.split("/")[0];
const functionBranches = ["feature", "bugfix", "support"];
const start = async () => {
  const config = cleanConfigSet(cmdConfig);
  const command = "start " + await getCommand(config);
  debug("start", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const combine = async () => {
  const requiredOptions = [];
  let delOptions = [], delArgs = [], requiredArgs = [];
  if (!functionBranches.includes(branchPrefix)) {
    delOptions = ["--as-feature", "--no-bugfix"];
    requiredArgs = ["type", "name"];
  } else {
    delArgs = ["type", "name"];
    switch (branchPrefix) {
      case "feature":
        delOptions = ["--as-feature"];
        break;
      case "support":
        delOptions = ["--as-feature"];
        break;
    }
  }
  const config = cleanConfigSet(cmdConfig$1, {
    delOptions,
    requiredOptions,
    delArgs,
    requiredArgs
  });
  const command = "combine " + await getCommand(config);
  debug("combine", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const end = async () => {
  let delArgs = [], requiredArgs = [];
  if (!functionBranches.includes(branchPrefix)) {
    requiredArgs = ["type", "name"];
  } else {
    delArgs = ["type", "name"];
  }
  const config = cleanConfigSet(cmdConfig$2, { delArgs, requiredArgs });
  const command = "end " + await getCommand(config);
  debug("end", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const update = async () => {
  let delArgs = [], requiredArgs = [];
  if (!functionBranches.includes(branchPrefix)) {
    requiredArgs = ["type", "name"];
  } else {
    delArgs = ["type", "name"];
  }
  const config = cleanConfigSet(cmdConfig$3, { delArgs, requiredArgs });
  const command = "update " + await getCommand(config);
  debug("update", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const undo = async () => {
  const config = cleanConfigSet(cmdConfig$4);
  const command = "undo " + await getCommand(config);
  debug("undo", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const redo = async () => {
  const config = cleanConfigSet(cmdConfig$5);
  const command = "redo " + await getCommand(config);
  debug("redo", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const branch = async () => {
  const config = cleanConfigSet(cmdConfig$6);
  const command = "branch " + await getCommand(config);
  debug("branch", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const build = async () => {
  const config = cleanConfigSet(cmdConfig$7);
  const command = "build " + await getCommand(config);
  debug("build", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const buildMp = async () => {
  const config = cleanConfigSet(cmdConfig$8);
  const command = "build-mp " + await getCommand(config);
  debug("build-mp", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const copy = async () => {
  const config = cleanConfigSet(cmdConfig$9);
  const command = "copy " + await getCommand(config);
  debug("copy", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const get = async () => {
  const config = cleanConfigSet(cmdConfig$a);
  const command = "get " + await getCommand(config);
  debug("get", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const save = async () => {
  const config = cleanConfigSet(cmdConfig$b);
  const command = "save " + await getCommand(config);
  debug("save", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const cleanbranch = async () => {
  const config = cleanConfigSet(cmdConfig$c);
  const command = "cleanbranch " + await getCommand(config);
  debug("cleanbranch", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const clean = async () => {
  const config = cleanConfigSet(cmdConfig$d);
  const command = "clean " + await getCommand(config);
  debug("clean", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const revert = async () => {
  const config = cleanConfigSet(cmdConfig$e);
  const command = "revert " + await getCommand(config);
  debug("revert", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const link = async () => {
  const config = cleanConfigSet(cmdConfig$f);
  const command = "link " + await getCommand(config);
  debug("link", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const unlink = async () => {
  const config = cleanConfigSet(cmdConfig$g);
  const command = "unlink " + await getCommand(config);
  debug("unlink", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const postmsg = async () => {
  const config = cleanConfigSet(cmdConfig$h);
  const command = "postmsg " + await getCommand(config);
  debug("postmsg", command);
  spawnSync("gitm", command.split(" "), { stdio: "inherit" });
};
const admin = {
  create: async () => {
    const config = cleanConfigSet(adminCreateConfig);
    const command = "admin create " + await getCommand(config);
    debug("admin create", command);
    spawnSync("gitm", command.split(" "), { stdio: "inherit" });
  },
  publish: async () => {
    const config = cleanConfigSet(adminPublishConfig);
    const command = "admin publish " + await getCommand(config);
    debug("admin publish", command);
    spawnSync("gitm", command.split(" "), { stdio: "inherit" });
  },
  update: async () => {
    const config = cleanConfigSet(adminUpdateConfig);
    const command = "admin update " + await getCommand(config);
    debug("admin update", command);
    spawnSync("gitm", command.split(" "), { stdio: "inherit" });
  },
  clean: async () => {
    const config = cleanConfigSet(adminCleanConfig);
    const command = "admin clean " + await getCommand(config);
    debug("admin clean", command);
    spawnSync("gitm", command.split(" "), { stdio: "inherit" });
  }
};

export { admin, branch, build, buildMp, clean, cleanbranch, combine, copy, end, get, link, postmsg, redo, revert, save, start, undo, unlink, update };
